# AI Content Creator

The AI Content Creator module is a powerful tool for generating high-quality
content for your Drupal website using OpenAI's advanced language models. 
It supports modern GPT models (GPT-3.5 Turbo, GPT-4) as well as legacy models,
providing flexible content generation capabilities.

## Features

- **Modern AI Models**: Support for GPT-3.5 Turbo, GPT-4, and GPT-4 Turbo
- **Flexible Configuration**: Customizable temperature, token limits, and model selection
- **Enhanced Security**: Improved API key handling with support for longer keys (up to 255 characters)
- **Better Error Handling**: User-friendly error messages and comprehensive logging
- **Content Integration**: Seamlessly integrates with Drupal node forms
- **Copy to Clipboard**: Easy content copying with one-click functionality
- **Responsive UI**: Modal dialog with improved user experience

### AI Content generator node form

![AI Content generator node form](https://i.imgur.com/EUHS0tz.png)

### AI Content generator setting form

![AI Content generator setting form](https://i.imgur.com/z9WD5Yz.png)


## Configuration

1. Navigate to Administration > Configuration >
   AI Content Creator API Settings (/admin/config/ai_content_creator)
   to configure OpenAI API settings

2. Configure the following settings:
   - **OpenAI URL endpoint**: The API endpoint (default: https://api.openai.com/v1/completions)
   - **OpenAI access token**: Your OpenAI API key (supports keys up to 255 characters)
   - **AI Model**: Choose from GPT-3.5 Turbo (recommended), GPT-4, GPT-4 Turbo, or legacy models
   - **Maximum tokens**: Set the maximum number of tokens to generate (1-4000)
   - **Temperature**: Control creativity (0 = focused, 1 = creative)
   - **Content types**: Select which content types will show the AI generator

3. The "AI Content Generator" section will appear in the enabled content types

## Usage

1. When creating or editing content in enabled content types, you'll see the "AI Content Generator" section
2. Enter a detailed prompt describing what content you want to generate
3. Click "Generate content" to create AI-powered content
4. Review the generated content in the modal dialog
5. Use "Copy to clipboard" to easily paste the content into your fields

## Requirements

- Drupal 8.8+ or Drupal 9/10
- Valid OpenAI API key
- Internet connection for API calls

## Troubleshooting

- **API Key Issues**: Ensure your OpenAI API key is valid and has sufficient credits
- **Rate Limits**: If you encounter rate limit errors, wait a few minutes before trying again
- **Empty Responses**: Try adjusting your prompt to be more specific or increase the token limit
- **Connection Errors**: Check your internet connection and OpenAI service status

## Maintainers && credit

- Abderrahim GHAZALI - [AbdeI](https://www.drupal.org/u/abdei)